==> fileslog-1.0.4.tar.gz: fileslog/src/Logger/FilesLog.php <==
<?php

namespace Drupal\fileslog\Logger;

use Drupal\Core\File\FileSystemInterface;
use Drupal\Core\Logger\LogMessageParserInterface;
use Drupal\Core\Logger\RfcLoggerTrait;
use Drupal\fileslog\FilesLogInterface;

/**
 * Redirects logging messages to fileslog.
 */
class FilesLog implements FilesLogInterface {
  use RfcLoggerTrait;

  /**
   * The message's placeholders parser.
   *
   * @var \Drupal\Core\Logger\LogMessageParserInterface
   */
  protected LogMessageParserInterface $parser;

  /**
   * Constructs a fileslog object.
   *
   * @param \Drupal\Core\Logger\LogMessageParserInterface $parser
   *   The parser to use when extracting message variables.
   */
  public function __construct(LogMessageParserInterface $parser) {
    $this->parser = $parser;
  }

  /**
   * {@inheritdoc}
   */
  public function log($level, string|\Stringable $message, array $context = []): void {
    global $base_url;

    // Populate the message placeholders and then replace them in the message.
    $message_placeholders = $this->parser->parseMessagePlaceholders($message, $context);
    $message = empty($message_placeholders) ? $message : strtr($message, $message_placeholders);

    $channel = $context['channel'];
    $entry = json_encode([
      'base_url' => $base_url,
      'timestamp' => $context['timestamp'],
      'type' => $channel,
      'ip' => $context['ip'],
      'request_uri' => $context['request_uri'],
      'referer' => $context['referer'],
      'severity' => $level,
      'uid' => $context['uid'],
      'link' => strip_tags($context['link']),
      'message' => strip_tags($message),
    ], JSON_PRETTY_PRINT);

    $this->filesLogWrapper($level, $channel, $entry);
  }

  /**
   * A fileslog wrapper to make fileslog functionality testable.
   *
   * @param int $level
   *   The log's severity.
   * @param string $channel
   *   The log's channel.
   * @param string $entry
   *   The entry to store in the log.
   */
  protected function filesLogWrapper(int $level, string $channel, string $entry) {
    /**
     * We have to add it this way to prevent circular reference errors.
     *
     * @var \Drupal\Core\File\FileSystemInterface $filesystem
     */
    $filesystem = \Drupal::service('file_system');

    // @todo Implement channel somehow, so we can filter on it easily.
    $directory = FilesLogInterface::DIRECTORY;
    $filesystem->prepareDirectory($directory, FileSystemInterface::CREATE_DIRECTORY);
    $filesystem->prepareDirectory($directory, FileSystemInterface::MODIFY_PERMISSIONS);
    $filesystem->saveData($entry, $directory . '/' . microtime(TRUE) . '-' . $level . '.json');
  }

}

==> fileslog-1.1.0.tar.gz: fileslog/src/Logger/FilesLog.php <==
<?php

namespace Drupal\fileslog\Logger;

use Drupal\Core\Logger\LogMessageParserInterface;
use Drupal\Core\Logger\RfcLoggerTrait;
use Drupal\fileslog\FilesLogInterface;

/**
 * Redirects logging messages to fileslog.
 */
class FilesLog implements FilesLogInterface {
  use RfcLoggerTrait;

  /**
   * The message's placeholders parser.
   *
   * @var \Drupal\Core\Logger\LogMessageParserInterface
   */
  protected LogMessageParserInterface $parser;

  /**
   * Constructs a fileslog object.
   *
   * @param \Drupal\Core\Logger\LogMessageParserInterface $parser
   *   The parser to use when extracting message variables.
   */
  public function __construct(LogMessageParserInterface $parser) {
    $this->parser = $parser;
  }

  /**
   * {@inheritdoc}
   */
  public function log($level, string|\Stringable $message, array $context = []): void {
    global $base_url;

    // Populate the message placeholders and then replace them in the message.
    $message_placeholders = $this->parser->parseMessagePlaceholders($message, $context);
    $message = empty($message_placeholders) ? $message : strtr($message, $message_placeholders);

    $channel = $context['channel'];
    $entry = json_encode([
      'base_url' => $base_url,
      'timestamp' => $context['timestamp'],
      'type' => $channel,
      'ip' => $context['ip'],
      'request_uri' => $context['request_uri'],
      'referer' => $context['referer'],
      'severity' => $level,
      'uid' => $context['uid'],
      'link' => strip_tags($context['link']),
      'message' => strip_tags($message),
    ], JSON_PRETTY_PRINT);

    /**
     * @var \Drupal\fileslog\FilesLogManagerInterface $files_log_manager
     */
    $files_log_manager = \Drupal::service('fileslog.manager');
    $files_log_manager->addLog($level, $channel, $entry);
  }

}
